scoretools.Container
====================

.. abjad-lineage:: abjad.tools.scoretools.Container.Container

.. autoclass:: abjad.tools.scoretools.Container.Container

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.scoretools.Container.Container.append
      ~abjad.tools.scoretools.Container.Container.extend
      ~abjad.tools.scoretools.Container.Container.index
      ~abjad.tools.scoretools.Container.Container.insert
      ~abjad.tools.scoretools.Container.Container.is_simultaneous
      ~abjad.tools.scoretools.Container.Container.pop
      ~abjad.tools.scoretools.Container.Container.remove
      ~abjad.tools.scoretools.Container.Container.reverse
      ~abjad.tools.scoretools.Container.Container.select_leaves
      ~abjad.tools.scoretools.Container.Container.select_notes_and_chords
      ~abjad.tools.scoretools.Container.Container.__contains__
      ~abjad.tools.scoretools.Container.Container.__copy__
      ~abjad.tools.scoretools.Container.Container.__delitem__
      ~abjad.tools.scoretools.Container.Container.__eq__
      ~abjad.tools.scoretools.Container.Container.__format__
      ~abjad.tools.scoretools.Container.Container.__getitem__
      ~abjad.tools.scoretools.Container.Container.__illustrate__
      ~abjad.tools.scoretools.Container.Container.__len__
      ~abjad.tools.scoretools.Container.Container.__mul__
      ~abjad.tools.scoretools.Container.Container.__ne__
      ~abjad.tools.scoretools.Container.Container.__repr__
      ~abjad.tools.scoretools.Container.Container.__rmul__
      ~abjad.tools.scoretools.Container.Container.__setitem__

Bases
-----

- :py:class:`scoretools.Component <abjad.tools.scoretools.Component.Component>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read/write properties
---------------------

.. autoattribute:: abjad.tools.scoretools.Container.Container.is_simultaneous
   :noindex:

Methods
-------

.. automethod:: abjad.tools.scoretools.Container.Container.append
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.extend
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.index
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.insert
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.pop
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.remove
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.reverse
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.select_leaves
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.select_notes_and_chords
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.scoretools.Container.Container.__contains__
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.__copy__
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.__delitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.__format__
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.__getitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.__illustrate__
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.__len__
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.__mul__
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.__rmul__
   :noindex:

.. automethod:: abjad.tools.scoretools.Container.Container.__setitem__
   :noindex:
